hyperspy\.tests\.mva package
============================

Submodules
----------

hyperspy\.tests\.mva\.test\_bss module
--------------------------------------

.. automodule:: hyperspy.tests.mva.test_bss
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.mva\.test\_decomposition module
------------------------------------------------

.. automodule:: hyperspy.tests.mva.test_decomposition
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.mva\.test\_export module
-----------------------------------------

.. automodule:: hyperspy.tests.mva.test_export
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.mva\.test\_onmf module
---------------------------------------

.. automodule:: hyperspy.tests.mva.test_onmf
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.mva\.test\_rpca module
---------------------------------------

.. automodule:: hyperspy.tests.mva.test_rpca
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.mva
    :members:
    :undoc-members:
    :show-inheritance:
